﻿using UnityEngine;
using System.Collections.Generic;
using System.IO;

public class DumpItems : Mod
{
    static bool ExtraSettingsAPI_Loaded = false;
    static string prefix = "[DumpItems]: ";
    static CraftingCategory[] categoryArr = {
        CraftingCategory.Tools, CraftingCategory.Other, CraftingCategory.Resources,
        CraftingCategory.Decorations, CraftingCategory.Equipment, CraftingCategory.Nothing,
        CraftingCategory.FoodWater, CraftingCategory.Navigation, CraftingCategory.CreativeMode,
        CraftingCategory.Hidden, CraftingCategory.Weapons, CraftingCategory.Skin };
    static string _f = Path.Combine(SaveAndLoad.AppPath, "DumpItems");
    public static string storage_folder
    {
        get
        {
            if (!Directory.Exists(_f))
                Directory.CreateDirectory(_f);
            return _f;
        }
    }

    public void Start()
    {
        Debug.Log(prefix + "Mod has been loaded!");
    }

    public void Update() { }

    public void OnModUnload()
    {
        Debug.Log(prefix + "Mod has been unloaded!");
    }

    public static void Dump(int category = -1)
    {
        string jsonStr = "[";
        string[] tmpArr = { };

        foreach (Item_Base itemBase in ItemManager.GetAllItems())
        {
            if (category > -1 && itemBase.settings_recipe.CraftingCategory != categoryArr[category]) { }
            else
            {
                string tmpCategory = CraftingCategoryToString(itemBase.settings_recipe.CraftingCategory);
                jsonStr += "{\n\"category\": \"" + tmpCategory + "\",\n\"UniqueIndex\": " + itemBase.UniqueIndex + ",\n\"UniqueName\": \"" + itemBase.UniqueName + "\",\n\"modded\": " + (itemBase.UniqueIndex > 1000).ToString().ToLower() + "\n},";
            }
        }

        jsonStr = jsonStr.Remove(jsonStr.Length - 1);
        jsonStr += "]";
        string tmpCtgName = category == -1 ? "all" : CraftingCategoryToString(categoryArr[category]).ToLower().Replace(" ", "-");
        string dumpCategoryFile = Path.Combine(storage_folder, "dump_" + tmpCtgName + ".json");
        File.WriteAllText(dumpCategoryFile, jsonStr);
        Debug.Log(prefix + "Dumped to \"" + dumpCategoryFile + "\"");
        return;
    }

    public static string CraftingCategoryToString(CraftingCategory ctg)
    {
        switch (ctg)
        {
            case CraftingCategory.Tools:
                return "Tools";
            case CraftingCategory.Other:
                return "Other";
            case CraftingCategory.Resources:
                return "Resources";
            case CraftingCategory.Decorations:
                return "Decorations";
            case CraftingCategory.Equipment:
                return "Equipments";
            case CraftingCategory.Nothing:
                return "Nothing";
            case CraftingCategory.FoodWater:
                return "Food and Water";
            case CraftingCategory.Navigation:
                return "Navigation";
            case CraftingCategory.CreativeMode:
                return "Creative Mode";
            case CraftingCategory.Hidden:
                return "Hidden";
            case CraftingCategory.Weapons:
                return "Weapons";
            case CraftingCategory.Skin:
                return "Skin";
            default:
                return "Unknown";
        }
    }

    [ConsoleCommand(name: "dump", docs: "Syntax: 'dump [0-11]' if used without args will dump all categories, if arg is a number from 0 to 11 it will dump the respective category (Tools, Other, Resources, Decorations, Equipment, Nothing, FoodWater, Navigation, CreativeMode, Hidden, Weapons, Skin)")]
    public static void DumpCmd(string[] args)
    {
        Dump((args.Length > 0 && int.TryParse(args[0], out int number)) ? number : -1);
    }


    // ----------------------------------------------------------------------
    // Extra Settings API

    public void ExtraSettingsAPI_Load()
    {
        Debug.Log(prefix + "Mod settings loaded");
    }

    public void ExtraSettingsAPI_Unload() { }
    public void ExtraSettingsAPI_SettingsOpen() { }
    public void ExtraSettingsAPI_SettingsClose() { }

    public void ExtraSettingsAPI_ButtonPress(string name)
    {
        switch (name) {
            case "dumpAll":
                Dump();
                break;
            case "dumpCategory":
                if (ExtraSettingsAPI_GetComboboxSelectedIndex("dumpCategoryChoose") >= 0)
                {
                    Dump(ExtraSettingsAPI_GetComboboxSelectedIndex("dumpCategoryChoose"));
                } else
                {
                    Debug.LogError(prefix + "Invalid category to dump");
                }
                break;
            case "browse":
                System.Diagnostics.Process.Start(storage_folder);
                break;
            default:
                Debug.LogError(prefix + "Button \"" + name + "\" pressed but not implemented in code cause the developer is dumb af, ping KingBR#3793 in the RaftModding discord server");
            break;
        }
    }

    public string ExtraSettingsAPI_HandleSliderText(string name, float value) => null;
    public static int ExtraSettingsAPI_GetComboboxSelectedIndex(string SettingName) => -1;
    public static string ExtraSettingsAPI_GetComboboxSelectedItem(string SettingName) => "";
    public static string[] ExtraSettingsAPI_GetComboboxContent(string SettingName) => new string[0];
    public static bool ExtraSettingsAPI_GetCheckboxState(string SettingName) => false;
    public static float ExtraSettingsAPI_GetSliderValue(string SettingName) => 0;
    public static float ExtraSettingsAPI_GetSliderRealValue(string SettingName) => 0;
    public static string ExtraSettingsAPI_GetKeybindName(string SettingName) => "";
    public static Keybind ExtraSettingsAPI_GetKeybind(string SettingName) => null;
    public static KeyCode ExtraSettingsAPI_GetKeybindMain(string SettingName) => KeyCode.None;
    public static KeyCode ExtraSettingsAPI_GetKeybindAlt(string SettingName) => KeyCode.None;
    public static string ExtraSettingsAPI_GetInputValue(string SettingName) => "";
    public static string ExtraSettingsAPI_GetDataValue(string SettingName, string subname) => "";
    public static string[] ExtraSettingsAPI_GetDataNames(string SettingName) => new string[0];
    public static string ExtraSettingsAPI_GetText(string SettingName) => ""; 
    public static void ExtraSettingsAPI_SetComboboxSelectedIndex(string SettingName, int value) { }
    public static void ExtraSettingsAPI_SetComboboxSelectedItem(string SettingName, string value) { }
    public static void ExtraSettingsAPI_SetComboboxContent(string SettingName, string[] value) { }
    public static void ExtraSettingsAPI_AddComboboxContent(string SettingName, string value) { }
    public static void ExtraSettingsAPI_ResetComboboxContent(string SettingName) { }
    public static void ExtraSettingsAPI_SetCheckboxState(string SettingName, bool value) { }
    public static void ExtraSettingsAPI_SetSliderValue(string SettingName, float value) { }
    public static void ExtraSettingsAPI_SetKeybindMain(string SettingName, KeyCode value) { }
    public static void ExtraSettingsAPI_SetKeybindAlt(string SettingName, KeyCode value) { }
    public static void ExtraSettingsAPI_SetInputValue(string SettingName, string value) { }
    public static void ExtraSettingsAPI_SetDataValue(string SettingName, string subname, string value) { }
    public static void ExtraSettingsAPI_SetDataValues(string SettingName, Dictionary<string, string> values) { }
    public static void ExtraSettingsAPI_SetText(string SettingName, string value) { } 
    public static void ExtraSettingsAPI_ResetSetting(string SettingName) { }
    public static void ExtraSettingsAPI_ResetAllSettings() { }
}